Package: xtbhst
Title: Bootstrap Slope Heterogeneity Test for Panel Data
Version: 1.0.1
Authors@R: c(
    person("Muhammad", "Alkhalaf", 
           email = "muhammedalkhalaf@gmail.com",
           role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0009-0002-2677-9246")),
    person("Tore", "Bersvendsen", role = "ctb"),
    person("Jan", "Ditzen", role = "ctb"))
Description: Implements the bootstrap slope heterogeneity test for panel data 
    based on Blomquist and Westerlund (2015) <doi:10.1007/s00181-015-0978-z>.
    Tests the null hypothesis that slope coefficients are homogeneous across
    cross-sectional units. Provides both standard and adjusted Delta statistics
    with bootstrap p-values. Supports partialling out of control variables and
    cross-sectional averages for dealing with cross-sectional dependence.
License: GPL-3
URL: https://github.com/muhammedalkhalaf/xtbhst
BugReports: https://github.com/muhammedalkhalaf/xtbhst/issues
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 3.5.0)
Imports: stats, graphics, grDevices
Suggests: testthat (>= 3.0.0), plm
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-03-09 17:14:06 UTC; acad_
Author: Muhammad Alkhalaf [aut, cre, cph] (ORCID:
    <https://orcid.org/0009-0002-2677-9246>),
  Tore Bersvendsen [ctb],
  Jan Ditzen [ctb]
Maintainer: Muhammad Alkhalaf <muhammedalkhalaf@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-13 13:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:13:06 UTC; unix
