#' @importFrom stats complete.cases density model.frame model.matrix
#'   model.response sd
#' @importFrom graphics abline hist legend lines
#' @importFrom grDevices dev.interactive devAskNewPage rgb
NULL
