% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods.R
\name{summary.xtbhst}
\alias{summary.xtbhst}
\title{Summary method for xtbhst objects}
\usage{
\method{summary}{xtbhst}(object, digits = 4L, ...)
}
\arguments{
\item{object}{An object of class \code{"xtbhst"}.}

\item{digits}{Number of digits to display (default: 4).}

\item{...}{Additional arguments (ignored).}
}
\value{
Invisibly returns a list with summary statistics.
}
\description{
Summary method for xtbhst objects
}
